@@ -42,7 +42,8 @@ def run(images,
     image_data = ImagesData(images=images, labels=labels,
                             validation_prop=validation_prop,
                             image_shape=image_shape,
-                            label_dict=label_dict)
+                            label_dict=label_dict,
+                            for_model_training=is_train_model)
     diamond_collector["image_data"] = image_data
     # plot
     if plot:
